@@ -3,7 +3,7 @@ Defines types related to surface meshes (`.obj` file format).
 """
 from civet.xfm import TransformableMixin
 from civet.minc import GenericMask
-from typing import TypeVar, Generic
+from typing import TypeVar, Generic, ClassVar
 from dataclasses import dataclass
 
 _S = TypeVar('_S', bound='GenericSurface')
@@ -12,8 +12,8 @@ _M = TypeVar('_M', bound=GenericMask)
 
 @dataclass(frozen=True)
 class GenericSurface(TransformableMixin[_S], Generic[_S]):
-    preferred_suffix = '.obj'
-    transform_program = 'transform_objects'
+    preferred_suffix: ClassVar[str] = '.obj'
+    transform_program: ClassVar[str] = 'transform_objects'
 
     def surface_mask2(self, in_volume: _M) -> _M:
         def command(output):
